@@ -31,6 +31,7 @@ from __future__ import absolute_import
 
 # import apis into sdk package
 from asposeslidescloud.apis.slides_api import SlidesApi
+from asposeslidescloud.apis.slides_async_api import SlidesAsyncApi
 
 # import ApiClient
 from asposeslidescloud.api_client import ApiClient
@@ -170,6 +171,7 @@ from asposeslidescloud.models.object_exist import ObjectExist
 from asposeslidescloud.models.ole_object_frame import OleObjectFrame
 from asposeslidescloud.models.one_value_chart_data_point import OneValueChartDataPoint
 from asposeslidescloud.models.one_value_series import OneValueSeries
+from asposeslidescloud.models.operation import Operation
 from asposeslidescloud.models.ordered_merge_request import OrderedMergeRequest
 from asposeslidescloud.models.outer_shadow_effect import OuterShadowEffect
 from asposeslidescloud.models.output_file import OutputFile
@@ -256,6 +258,8 @@ from asposeslidescloud.models.svg_export_options import SvgExportOptions
 from asposeslidescloud.models.swf_export_options import SwfExportOptions
 from asposeslidescloud.models.table import Table
 from asposeslidescloud.models.table_cell import TableCell
+from asposeslidescloud.models.table_cell_merge_options import TableCellMergeOptions
+from asposeslidescloud.models.table_cell_split_type import TableCellSplitType
 from asposeslidescloud.models.table_column import TableColumn
 from asposeslidescloud.models.table_row import TableRow
 from asposeslidescloud.models.task import Task
@@ -270,6 +274,9 @@ from asposeslidescloud.models.tiff_export_options import TiffExportOptions
 from asposeslidescloud.models.tint_effect import TintEffect
 from asposeslidescloud.models.update_background import UpdateBackground
 from asposeslidescloud.models.update_shape import UpdateShape
+from asposeslidescloud.models.vba_module import VbaModule
+from asposeslidescloud.models.vba_project import VbaProject
+from asposeslidescloud.models.vba_reference import VbaReference
 from asposeslidescloud.models.video_export_options import VideoExportOptions
 from asposeslidescloud.models.video_frame import VideoFrame
 from asposeslidescloud.models.view_properties import ViewProperties
