@@ -45,6 +45,7 @@ class BubbleSeries(XYSeries):
     swagger_types = {
         'type': 'str',
         'name': 'str',
+        'data_source_for_series_name': 'DataSource',
         'is_color_varied': 'bool',
         'inverted_solid_fill_color': 'str',
         'smooth': 'bool',
@@ -59,13 +60,17 @@ class BubbleSeries(XYSeries):
         'data_point_type': 'str',
         'number_format_of_y_values': 'str',
         'number_format_of_x_values': 'str',
+        'data_source_for_x_values': 'DataSource',
+        'data_source_for_y_values': 'DataSource',
         'data_points': 'list[BubbleChartDataPoint]',
-        'number_format_of_bubble_sizes': 'str'
+        'number_format_of_bubble_sizes': 'str',
+        'data_source_for_bubble_size_values': 'DataSource'
     }
 
     attribute_map = {
         'type': 'type',
         'name': 'name',
+        'data_source_for_series_name': 'dataSourceForSeriesName',
         'is_color_varied': 'isColorVaried',
         'inverted_solid_fill_color': 'invertedSolidFillColor',
         'smooth': 'smooth',
@@ -80,26 +85,32 @@ class BubbleSeries(XYSeries):
         'data_point_type': 'dataPointType',
         'number_format_of_y_values': 'numberFormatOfYValues',
         'number_format_of_x_values': 'numberFormatOfXValues',
+        'data_source_for_x_values': 'dataSourceForXValues',
+        'data_source_for_y_values': 'dataSourceForYValues',
         'data_points': 'dataPoints',
-        'number_format_of_bubble_sizes': 'numberFormatOfBubbleSizes'
+        'number_format_of_bubble_sizes': 'numberFormatOfBubbleSizes',
+        'data_source_for_bubble_size_values': 'dataSourceForBubbleSizeValues'
     }
 
     type_determiners = {
         'dataPointType': 'Bubble',
     }
 
-    def __init__(self, type=None, name=None, is_color_varied=None, inverted_solid_fill_color=None, smooth=None, plot_on_second_axis=None, order=None, invert_if_negative=None, explosion=None, marker=None, fill_format=None, effect_format=None, line_format=None, data_point_type='Bubble', number_format_of_y_values=None, number_format_of_x_values=None, data_points=None, number_format_of_bubble_sizes=None):  # noqa: E501
+    def __init__(self, type=None, name=None, data_source_for_series_name=None, is_color_varied=None, inverted_solid_fill_color=None, smooth=None, plot_on_second_axis=None, order=None, invert_if_negative=None, explosion=None, marker=None, fill_format=None, effect_format=None, line_format=None, data_point_type='Bubble', number_format_of_y_values=None, number_format_of_x_values=None, data_source_for_x_values=None, data_source_for_y_values=None, data_points=None, number_format_of_bubble_sizes=None, data_source_for_bubble_size_values=None):  # noqa: E501
         """BubbleSeries - a model defined in Swagger"""  # noqa: E501
-        super(BubbleSeries, self).__init__(type, name, is_color_varied, inverted_solid_fill_color, smooth, plot_on_second_axis, order, invert_if_negative, explosion, marker, fill_format, effect_format, line_format, data_point_type, number_format_of_y_values, number_format_of_x_values)
+        super(BubbleSeries, self).__init__(type, name, data_source_for_series_name, is_color_varied, inverted_solid_fill_color, smooth, plot_on_second_axis, order, invert_if_negative, explosion, marker, fill_format, effect_format, line_format, data_point_type, number_format_of_y_values, number_format_of_x_values, data_source_for_x_values, data_source_for_y_values)
 
         self._data_points = None
         self._number_format_of_bubble_sizes = None
+        self._data_source_for_bubble_size_values = None
         self.data_point_type = 'Bubble'
 
         if data_points is not None:
             self.data_points = data_points
         if number_format_of_bubble_sizes is not None:
             self.number_format_of_bubble_sizes = number_format_of_bubble_sizes
+        if data_source_for_bubble_size_values is not None:
+            self.data_source_for_bubble_size_values = data_source_for_bubble_size_values
 
     @property
     def data_points(self):
@@ -145,6 +156,28 @@ class BubbleSeries(XYSeries):
         """
         self._number_format_of_bubble_sizes = number_format_of_bubble_sizes
 
+    @property
+    def data_source_for_bubble_size_values(self):
+        """Gets the data_source_for_bubble_size_values of this BubbleSeries.  # noqa: E501
+
+        Data source type for Bubble size values.  # noqa: E501
+
+        :return: The data_source_for_bubble_size_values of this BubbleSeries.  # noqa: E501
+        :rtype: DataSource
+        """
+        return self._data_source_for_bubble_size_values
+
+    @data_source_for_bubble_size_values.setter
+    def data_source_for_bubble_size_values(self, data_source_for_bubble_size_values):
+        """Sets the data_source_for_bubble_size_values of this BubbleSeries.
+
+        Data source type for Bubble size values.  # noqa: E501
+
+        :param data_source_for_bubble_size_values: The data_source_for_bubble_size_values of this BubbleSeries.  # noqa: E501
+        :type: DataSource
+        """
+        self._data_source_for_bubble_size_values = data_source_for_bubble_size_values
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
